ace.define("ace/mode/pxplus_highlight_rules",["require","exports","module","ace/lib/oop","ace/mode/text_highlight_rules"], function(require, exports, module) {
"use strict";

var oop = require("../lib/oop");
var TextHighlightRules = require("./text_highlight_rules").TextHighlightRules;

var PxPlusHighlightRules = function() {

    this.$rules = {
    "start": [
        {
            token: [
                "meta.ending-space"
            ],
            regex: "$"
        },
        {
            token: [
                null
            ],
            regex: "^(?=\\t)",
            next: "state_3"
        },
        {
            token: [null],
            regex: "^(?= )",
            next: "state_4"
        },
        {
            token: [
                "text",
                "storage.type.function",
                "text",
                "entity.name.function",
                "text",
                "punctuation.definition.parameters",
                "variable.parameter.function",
                "punctuation.definition.parameters"
            ],
            regex: "^(\\s*)(Function|Sub)(\\s*)([a-zA-Z_]\\w*)(\\s*)(\\()([^)]*)(\\))"
        },
        {
            token: "punctuation.definition.comment",
            regex: "REM ",
            next: "comment",
            caseInsensitive: true
        },
		{
            token: "punctuation.definition.comment",
            regex: "!.*",
            caseInsensitive: true
        },
        {
            token: [
                "keyword.control"
            ],
			regex: "\\b(?:If|Then|Else|End_If|While|Wend|For|To|Next|Switch|Case|Default|Select|Go to|Gosub|Return|Continue|Until|Repeat|Try|Catch|Finally|End_Try|Run|Call|Perform|End|Exit|Stop|Quit)\\b",
            caseInsensitive: true
        },
        {
            token: [
                "keyword.directive"
            ],
			regex: "\\b(?:Set_param)\\b",
            caseInsensitive: true
        },
        {
            token: "keyword.operator",
            regex: "\\b(?:And|Or)\\b",
            caseInsensitive: true
        },
        {
            token: "storage.type",
            regex: "Dim|Call|Class|Const|Dim|Redim|Function|Set|Let|Get|New|Randomize|Option Explicit|On Error Resume Next|On Error GoTo",
            caseInsensitive: true
        },
        {
            token: "storage.modifier",
            regex: "\\b(?:Private|Public|Default)\\b",
            caseInsensitive: true
        },
        {
            token: "punctuation.definition.string.begin",
            regex: '"',
            next: "string"
        },
        {
            token: "punctuation.definition.string.hexstring",
            regex: '\\$([0-9A-Fa-f][0-9A-Fa-f])*\\$',
        },
        {
            token: "punctuation.definition.string.mnemonic",
            regex: "'_?[a-zA-Z0-9]+'",
        },
        {
            token: "support.class",
            regex: "\\b(?:Application|ObjectContext|Request|Response|Server|Session)\\b",
            caseInsensitive: true
        },
        {
            token: "support.class.collection",
            regex: "\\b(?:Contents|StaticObjects|ClientCertificate|Cookies|Form|QueryString|ServerVariables)\\b",
            caseInsensitive: true
        },
        {
            token: "support.function",
            regex: "\\b(?:Lock|Unlock|SetAbort|SetComplete|BinaryRead|AddHeader|AppendToLog|BinaryWrite|Clear|End|Flush|Redirect|Write|CreateObject|HTMLEncode|MapPath|URLEncode|Abandon|Convert|Regex)\\b",
            caseInsensitive: true
        },
        {
            token: "support.function",
            regex: "\\b(?:@X|@Y|Abs|Acs|And|Arg|Asc|Asn|Ath|Atn|Bin|Bsz|Chg|Chr|Cmp|Cos|Cpl|Crc|Cse|Ctl|Cvs|Dec|Dim|Dir|Dll|Dlx|Dsk|Dte|Env|Ept|Err|Evn|Evs|Exp|Ffn|Fib|Fid|Fin|Fpt|Gap|Gbl|Gep|Hsa|Hsh|Hta|Hwn|I3E|I86|Ind|Int|Iol|Ior|Jst|Jul|Kec|Kef|Kel|Ken|Kep|Key|Kgn|Lcs|Len|Lno|Log|Lrc|Lst|Max|Mem|Mid|Min|Mnm|Mod|Msg|Msk|Mxc|Mxl|New|Not|Nul|Num|Obj|Opt|Pad|Pck|Pfx|Pgm|Pos|Prc|Prm|Pth|Pub|Rcd|Rdx|Rec|Ref|Rnd|Rno|Sep|Sgn|Sin|Sqr|Srt|Ssz|Stk|Stp|Str|Sub|Swp|Sys|Tan|Tbl|Tcb|Tmr|Trx|Try|Tsk|Txh|Txw|Ucp|Ucs|Upk|Val|Vin|Vis|Xeq|Xfa|Xml|Xor|)\\b\\?",
            caseInsensitive: true
        },
        {
            token: [
                "constant.numeric"
            ],
            regex: "-?\\b(?:(?:0(?:x|X)[0-9a-fA-F]*)|(?:(?:[0-9]+\\.?[0-9]*)|(?:\\.[0-9]+))(?:(?:e|E)(?:\\+|-)?[0-9]+)?)(?:L|l|UL|ul|u|U|F|f)?\\b"
        },
        {
            token: "support.type.vb",
            regex: "\\b(?:vbtrue|vbfalse|vbcr|vbcrlf|vbformfeed|vblf|vbnewline|vbnullchar|vbnullstring|int32|vbtab|vbverticaltab|vbbinarycompare|vbtextcomparevbsunday|vbmonday|vbtuesday|vbwednesday|vbthursday|vbfriday|vbsaturday|vbusesystemdayofweek|vbfirstjan1|vbfirstfourdays|vbfirstfullweek|vbgeneraldate|vblongdate|vbshortdate|vblongtime|vbshorttime|vbobjecterror|vbEmpty|vbNull|vbInteger|vbLong|vbSingle|vbDouble|vbCurrency|vbDate|vbString|vbObject|vbError|vbBoolean|vbVariant|vbDataObject|vbDecimal|vbByte|vbArray)\\b",
            caseInsensitive: true
        },
        {
            token: [
                "entity.name.function"
            ],
            regex: "(?:(\\b[a-zA-Z_x7f-xff][a-zA-Z0-9_x7f-xff]*?\\b)(?=\\(\\)?))"
        },
        {
            token: [
                "keyword.operator"
            ],
            regex: "\\-|\\+|\\*\\\/|\\>|\\<|\\=|\\&"
        }
    ],
    "state_3": [
        {
            token: [
                "meta.odd-tab.tabs",
                "meta.even-tab.tabs"
            ],
            regex: "(\\t)(\\t)?"
        },
        {
            token: "meta.leading-space",
            regex: "(?=[^\\t])",
            next: "start"
        },
        {
            token: "meta.leading-space",
            regex: ".",
            next: "state_3"
        }
    ],
    "state_4": [
        {
            token: ["meta.odd-tab.spaces", "meta.even-tab.spaces"],
            regex: "(  )(  )?"
        },
        {
            token: "meta.leading-space",
            regex: "(?=[^ ])",
            next: "start"
        },
        {
            defaultToken: "meta.leading-space"
        }
    ],
    "comment": [
        {
            token: "comment.line.apostrophe",
            regex: "$|(?=(?:%>))",
            next: "start"
        },
        {
            defaultToken: "comment.line.apostrophe"
        }
    ],
    "string": [
        {
            token: "constant.character.escape.apostrophe",
            regex: '""'
        },
        {
            token: "string.quoted.double",
            regex: '"',
            next: "start"
        },
        {
            defaultToken: "string.quoted.double"
        }
    ]
}

};

oop.inherits(PxPlusHighlightRules, TextHighlightRules);

exports.PxPlusHighlightRules = PxPlusHighlightRules;
});

ace.define("ace/mode/pxplus",["require","exports","module","ace/lib/oop","ace/mode/text","ace/mode/pxplus_highlight_rules"], function(require, exports, module) {
"use strict";

var oop = require("../lib/oop");
var TextMode = require("./text").Mode;
var PxPlusHighlightRules = require("./pxplus_highlight_rules").PxPlusHighlightRules;

var Mode = function() {
    this.HighlightRules = PxPlusHighlightRules;
};
oop.inherits(Mode, TextMode);

(function() {
       
    this.lineCommentStart = ["!", "REM"];
    
    this.$id = "ace/mode/pxplus";
}).call(Mode.prototype);

exports.Mode = Mode;
});
